.. Copyright 2016,2021 IBM Corp. All Rights Reserved.
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
..    http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..

zhmcclient - A pure Python client library for the IBM Z HMC Web Services API
****************************************************************************

.. _GitHub project page: https://github.com/zhmcclient/python-zhmcclient

.. toctree::
   :maxdepth: 2
   :numbered:

   intro.rst
   tutorial.rst
   concepts.rst
   general.rst
   resources.rst
   notifications.rst
   mocksupport.rst
   development.rst
   security.rst
   appendix.rst
   changes.rst
